@@ -1,7 +1,7 @@
 """
 file path manipulation
 
-Copyright: 2011-2015 Ethan Furman
+Copyright: 2011-2018 Ethan Furman
 """
 
 from os import F_OK, R_OK, W_OK, X_OK
@@ -199,10 +199,6 @@ class Path(object):
     def link(source, link_name):
         return Path(source).link(link_name)
 
-    @staticmethod
-    def listdir(subdir):
-        return Path(subdir).listdir()
-
     if hasattr(_os, 'lstat'):
 
         @staticmethod
@@ -466,9 +462,12 @@ class Methods(object):
             if dir not in (self._CUR_DIR, self._PREV_DIR):
                 new_path.append(dir)
             elif dir == self._PREV_DIR:
-                if not new_path or new_path[-1] in (self._EMPTY, self._SLASH):
+                if len(new_path) == 1 and new_path[0] in (self._SLASH):
                     raise ValueError("Too many .. dirs in %s" % dirs)
-                new_path.pop()
+                elif not new_path or new_path[-1] == self._PREV_DIR:
+                    new_path.append(dir)
+                else:
+                    new_path.pop()
         if len(new_path) > 1 and new_path[0] == self._SLASH:
             new_path[0] = self._EMPTY
         dirs = self._SLASH.join(new_path)
@@ -1213,6 +1212,16 @@ else:
     bPath.basecls = bPath, bytes
     uPath.basecls = uPath, unicode
 
+# add xmlrpc support
+if _py_ver < (3, 0):
+    from xmlrpclib import Marshaller
+    Marshaller.dispatch[bPath] = Marshaller.dump_string
+else:
+    from xmlrpc.client import Marshaller
+    Marshaller.dispatch[bPath] = Marshaller.dump_bytes
+Marshaller.dispatch[uPath] = Marshaller.dump_unicode
+del Marshaller
+
 def base_class(*paths):
     result = []
     for p in paths:
